doc="""Supporting tool for publication Joule *Heating in Nanowires*, by 

Hans Fangohr, Dmitri S. Chernyshenko, Matteo Franchin, Thomas
Fischbacher, Guido Meier, Joule heating in nanowires,
Physical Review B, 85, 054437 (2011)
Online: 
- Published version: http://prb.aps.org/abstract/PRB/v84/i5/e054437
- Preprint: http://arxiv.org/abs/1012.4304
- Preprint: http://eprints.soton.ac.uk/184837/

Please see
http://www.soton.ac.uk/~fangohr/publications/2011-joule-heating-in-nanowires.html
for an up-to-date reference and newer versions of this tool. 
All equations below refer to this publication.

  Disclaimer: The authors nor anybody else assume any responsibility
  whatsoever for the use of this too by other parties, and makes no
  guarantees, expressed or implied, about its quality, reliability, or
  any other characteristic.

  $Id: 2d.py,v 7950bc7b47f0 2012/05/30 23:25:05 fangohr $

Notes:
  * this program should only be used for a two-dimensional substrate
    (i.e. thickness of substrate << length of wire)
"""



import sys              #Standard Python Library

#import objects we need from nanowirelib
try:
    import nanowirelib
except ImportError:     
    print "Can't find file 'nanowirelib.py'. Needs to be in the same directory."
    print "All files can be downloaded from"
    print "http://www.soton.ac.uk/~fangohr/publications/2011-joule-heating-in-nanowires.html"
    print "Stopping here; sorry."
    sys.exit(1)

import time                                                  #Python's time module
from numpy import logspace,log10                             #from numpy Python module
from nanowirelib import T2d,nanowirewithnotchonSiN           #from file 'nanowirelib.py'

#Should we show a plot of the graph and display on screen? ('True' for yes, 'False' for no)
show_plot = True

#Should we save a pdf and png image of the graph? (Can also do interactively in figure window)
#Will be saved to file 'T_2d_substrate.pdf' and 'T_2d_substrate.png'
save_plot = True
filenameroot = 'T_2d_substrate'

#Should we save the data in a table in a text file (saved to 'T_2d_substrate.txt').
save_data_to_textfile = True

#Should we show the finite element simulation for comparison (zigzag wire, Sect 3C)
show_finite_element_simulation_data = True

#Generic constants
nm=1e-9   #define 1 nanometre to be 10^{-9}

#define problem constants (enter your own values here)

#Experimental parameters (as in section 3C "Notch wire on membrane
#substrate"), but you can modify these to match your own experiment.

j=1.0e12        #current density (A/m^2)
w=150*nm        #width of nanowire (m)
h=30*nm         #height (=thickness) of nanowire (m)
k=3.2           #thermal conductivity of substrate (W/(m K))
sigma=1./25e-8  #electric conductivity nanowire (1/(Ohm m) = A^2 s^3 / kg m^3)
rho= 3000       #density of substrate (kg/m^3)
C=700           #specific heat capacity of substrate (J/(kg K))
L=5e-6          #length of wire (m)
d=100*nm        #thickness of substrate (m)

#Parameters for plot/data output can be changed below (look for 'min_t' and 'max_t').

print "==== (Program starts at %s) ====" % time.asctime()
print 
print doc
print 
print "Parameters used in this run (all in SI units, see source for dimensions) are:"+\
      "\n\tj=%g\n\tw=%g\n\th=%g\n\tk=%g\n\tsigma=%g\n\trho=%g\n\tC=%g\n\tL=%g\n\td=%g" % \
      (j,w,h,k,sigma,rho,C,L,d)
print
print "For these parameters, we compute the maximum substrate temperature increase"
print "as a function of time (using Eq 8)."
print 

#create array of values of t starting from min_t up to max_t using 200 steps and log spacing
min_t = 1e-12    #seconds (i.e. 1 pico second)
max_t = 100e-6   #seconds (i.e. 100 microseconds)
t = logspace(log10(min_t),log10(max_t),200)

#compute the corresponding temperatures using the analytical equation for 2d substrate
#Fangohr et al, Physical Review B 85, 054437 (2011) 
T2ddata = T2d(t,j,w,h,k,sigma,rho,C,d,L,alpha=0.5)

assert len(t) == len(T2ddata), "Internal error, please report to authors"

if save_data_to_textfile:
    filename = filenameroot+'.txt'
    f=open(filename,'w')
    for i in xrange(len(t)):
        f.write('%15g\t%15g\n' % (t[i],T2ddata[i]))
    f.close()
    print "-> Have saved data to %s (tab-separated)" % filename

if show_plot or save_plot:
    import matplotlib.pyplot as plt
    plt.semilogx(t,T2ddata,'-',label='analytical approx (eq 8) for 2d substrate',lw=3)
    plt.xlabel('time [s]')
    plt.ylabel('Delta T [K]')
    plt.title('Plot produced with 2d.py on %s' % time.asctime())
    plt.grid()

    #if desired, plot FE solution. Makes only sense for parameters
    #for zigzag nanowire simulation as in Sec 3C of publication.)
    if show_finite_element_simulation_data:
        t,maxTwire,maxTsubstrate,minTsubstrate = nanowirewithnotchonSiN()
        plt.semilogx(t,maxTwire,'-',lw=1.5,label='max(T) in wire (FE result Sec 3C)')
        plt.semilogx(t,maxTsubstrate,'--',label='max(T) in substrate (FE result Sec 3C)')
        plt.semilogx(t,minTsubstrate,'-',label='min(T) in substrate (FE result Sec 3C)')

    plt.legend(loc='best')
    if save_plot:
        plt.savefig(filenameroot+'.png')
        print "-> Have created plot and saved to %s.png." % (filenameroot)
        plt.savefig(filenameroot+'.pdf')
        print "-> Have created plot and saved to %s.pdf." % (filenameroot)
    if show_plot:
        print "Press CTRL+C to stop program, or close figure window"
        plt.show()

print
print "==== Program completed ===="
print "If you use results obtained with this tool in publications,"
print "please cite Physical Review B, 85, 054437 (2011)
print "==========================="
