from __future__ import division

"""Supporting code for publication Joule *Heating in Nanowires*, by 
Hans Fangohr, Dmitri S. Chernyshenko, Matteo Franchin, Thomas Fischbacher, Guido Meier
Physical Review B, 85, 054437 (2011)

Please see http://www.soton.ac.uk/~fangohr/publications/2011-joule-heating-in-nanowires.html
for newer versions of this tool.

All equations below refer to this publication.

$Id: nanowirelib.py,v 7950bc7b47f0 2012/05/30 23:25:05 fangohr $

"""

software_requirements_doc=\
"""These python functions need Python 2.x.  In addition two module
which are not part of the Standard Python Library are required: the
modules 'numpy' and, if desired for plotting, 'matplotlib'.

The numpy module can be downloaded from http://numpy.scipy.org/ and
the matplotlib module (for plotting) from
http://matplotlib.sourceforge.net/

It may be easier to install the Enthought Python Edition (which is
free for academic use) and which provides numpy, matplotlib and many
other useful libraries together with Python. It tends to work out of
the box and installation is easy for all major platforms (Windows,
Linux, Mac).  See http://www.enthought.com/products/epd.php
"""



import sys

try:
    import numpy
except ImportError:
    print "Could not import numpy:\n"+software_requirements_doc
    print "Halting program now. "
    sys.exit(1)

from numpy import pi,sqrt
from numpy import arcsinh as asinh

def estimate_T3d_max_t(rho,k,C,L):
    """Returns an estimated time (seconds) for the validity
    of the T^{3d} equation as provided by function T3d. We
    often refer to this time as tc.

    Equation 5 in publication, originally derived by You etal, APL 89 222513 (2006).

    Input parameters

    rho: density of substrate (kg/m^3)
    k  : thermal conductivity substrate (W/(m K))
    C  : specific heat capacity (J/(kg K))
    L  : length of nanowire
    """
    return (L/2.)**2*rho*C/float(k)

def T3d(t,j,w,h,k,sigma,rho,C,alpha=0.5):
    """Computes an analytical approximation of the maximum substrate temperature
    for a nanowire on a substrate. Equation derived by You et al (2006).

    Input parameters:
    t : time (seconds)                  (can be single float or numpy array)
    j : current density (A/m^2)
    w : width of nanowire (m)
    h : height (=thickness) of nanowire (m)
    k : thermal conductivity substrate (W/(m K))
    sigma : electric conductivity nanowire (1/Ohm m = A^2 s^3 / kg m^3)
    rho: density of substrate (kg/m^3)
    C  : specific heat capacity (J/(kg K))
    alpha: empirical parameter (0.5-0.6, See You et al, APL 89 222513 2006)

    Returns the estimated maximum substrate temperature for all values of t
    (either as a float or numpy array: return type is the same as the type of
    input parameter t).

    Uses equation 5 from publication. Model from You etal, APL 89 222513 2006
    """
    return w*h*j*j/(pi*k*sigma)*asinh(2*sqrt(t*k/float(rho*C))/float(alpha*w))

def T2d(t,j,w,h,k,sigma,rho,C,d,L,alpha=0.5):
    """Computes an analytical approximation of the maximum substrate temperature
    for a 2d substrate.

    Input parameters:
    t : time (seconds)                  (can be single float or numpy array)
    j : current density (A/m^2)
    w : width of nanowire (m)
    h : height (=thickness) of nanowire (m)
    k : thermal conductivity substrate (W/(m K))
    sigma : electric conductivity nanowire (1/Ohm m = A^2 s^3 / kg m^3)
    rho: density of substrate (kg/m^3)
    C  : specific heat capacity (J/(kg K))
    d : height (=thickness) of substrate
    L : length of nanowire
    alpha: empirical parameter (0.5-0.6, See You et al, APL 89 222513 2006)
    
    Returns the estimated maximum substrate temperature for all values of t
    (either as a float or numpy array: return type is the same as the type of
    input parameter t).

    Using equation 8 in publication, Fangohr et al PRB 85, 054437 (2011)

    """
    return w*L*h*j*j/(2*d*pi*k*sigma)*asinh(2*sqrt(t*k/float(rho*C))/float(alpha*L))

def zigzagdata():
    """returns tuple of numpy.array objects:

    (time, max(T) in nanowire, max(T) in substrate, min(T) in substrate)

    for Zigzag wire case study 5 (section 3E in publication).

    source file: results/zigzag_3d/all_time_temp.dat"""

    datastr =  """0.1000720779E-07  0.0000000000E+00  0.0000000000E+00  0.0000000000E+00  
  0.2001441557E-07  0.4736383695E-02 -0.2004983219E-09  0.2001346575E-02  
  0.3002162336E-07  0.1417895600E-01 -0.6020280515E-09  0.5977153068E-02  
  0.6004324671E-07  0.4224103488E-01 -0.1811764444E-08  0.1764227005E-01  
  0.1501081168E-06  0.1255235530E+00 -0.5443353246E-08  0.5135229205E-01  
  0.4203027270E-06  0.3734625257E+00 -0.1561581227E-07  0.1498881304E+00  
  0.7365304930E-06  0.6547812787E+00 -0.2541124234E-07  0.2657523946E+00  
  0.1052758259E-05  0.9179204074E+00 -0.3284399124E-07  0.3827767350E+00  
  0.1368986025E-05  0.1161752896E+01 -0.3829891424E-07  0.4997713946E+00  
  0.1685213791E-05  0.1388456231E+01 -0.4207029964E-07  0.6159265834E+00  
  0.2001441557E-05  0.1600206721E+01 -0.4441720749E-07  0.7306459403E+00  
  0.2317669323E-05  0.1799067860E+01 -0.4557621329E-07  0.8436010192E+00  
  0.2633897089E-05  0.1986753434E+01 -0.4575827571E-07  0.9545700857E+00  
  0.2950124855E-05  0.2164687528E+01 -0.4514843236E-07  0.1063432896E+01  
  0.3162277660E-05  0.2279156638E+01 -0.4437196542E-07  0.1135254222E+01  
  0.3374430465E-05  0.2390070879E+01 -0.4335435446E-07  0.1206091270E+01  
  0.3586583270E-05  0.2497692588E+01 -0.4213317463E-07  0.1275944546E+01  
  0.4223041685E-05  0.2803338020E+01 -0.3760914535E-07  0.1479712311E+01  
  0.5223041685E-05  0.3239750239E+01 -0.2902825499E-07  0.1783132518E+01  
  0.6223041685E-05  0.3633354587E+01 -0.1998646678E-07  0.2067692584E+01  
  0.7223041685E-05  0.3993622562E+01 -0.1146426085E-07  0.2335492846E+01  
  0.8223041685E-05  0.4327089271E+01 -0.3921865457E-08  0.2588549871E+01  
  0.9223041685E-05  0.4638466608E+01  0.2470438195E-08  0.2828664646E+01  
  0.1000000000E-04  0.4867356049E+01  0.6628761603E-08  0.3007263460E+01  
  0.1077695831E-04  0.5086358808E+01  0.1011117289E-07  0.3179643243E+01  
  0.1155391663E-04  0.5296535078E+01  0.1296426326E-07  0.3346366698E+01  
  0.1388479157E-04  0.5883428121E+01  0.1840790213E-07  0.3817935914E+01  
  0.1704706923E-04  0.6595234760E+01  0.2021337993E-07  0.4401335866E+01  
  0.2020934689E-04  0.7233754135E+01  0.1817045410E-07  0.4934731181E+01  
  0.2337162455E-04  0.7817157579E+01  0.1442426784E-07  0.5429756334E+01  
  0.2653390221E-04  0.8357226473E+01  0.1027599528E-07  0.5894035062E+01  
  0.2969617987E-04  0.8862021294E+01  0.6426187458E-08  0.6332823280E+01  
  0.3162277660E-04  0.9154662851E+01  0.4371703569E-08  0.6589231334E+01  
  0.3354937333E-04  0.9437420016E+01  0.2582098638E-08  0.6838304092E+01  
  0.3547597006E-04  0.9711131812E+01  0.1060828048E-08  0.7080609522E+01  
  0.4125576024E-04  0.1048563177E+02 -0.2074098852E-08  0.7772174450E+01  
  0.5125576024E-04  0.1168996380E+02 -0.3858546548E-08  0.8864136242E+01  
  0.6125576024E-04  0.1275879289E+02 -0.3185531976E-08  0.9849455563E+01  
  0.7125576024E-04  0.1372379816E+02 -0.1939352530E-08  0.1075095683E+02  
  0.8125576024E-04  0.1460570184E+02 -0.9337076933E-09  0.1158377982E+02  
  0.9125576024E-04  0.1541915813E+02 -0.3541540148E-09  0.1235875109E+02  
  0.1000000000E-03  0.1608282728E+02 -0.1514033255E-09  0.1299532748E+02  
  0.1087442398E-03  0.1670816580E+02 -0.1412280373E-09  0.1359823658E+02  
  0.1174884795E-03  0.1729970254E+02 -0.2423221041E-09  0.1417099726E+02  
  0.1437211988E-03  0.1891006845E+02 -0.6587573118E-09  0.1573938657E+02  
  0.1753439754E-03  0.2058675125E+02 -0.9093529911E-09  0.1738362292E+02  
  0.2069667520E-03  0.2204665278E+02 -0.7768506187E-09  0.1882091158E+02  
  0.2385895286E-03  0.2334131920E+02 -0.5277997401E-09  0.2009779424E+02  
  0.2702123052E-03  0.2450516134E+02 -0.3640094325E-09  0.2124648386E+02  
  0.3018350818E-03  0.2556255847E+02 -0.3462808939E-09  0.2229030868E+02  
  0.3162277660E-03  0.2601321497E+02 -0.3849972508E-09  0.2273516225E+02  
  0.3306204502E-03  0.2644707357E+02 -0.4471159437E-09  0.2316339468E+02  
  0.3450131344E-03  0.2686533989E+02 -0.5279071645E-09  0.2357618849E+02  
  0.3881911871E-03  0.2803838166E+02 -0.8288408824E-09  0.2473355119E+02  
  0.4881911871E-03  0.3038043708E+02 -0.1452933631E-08  0.2704242809E+02  
  0.5881911871E-03  0.3232239332E+02 -0.1599002045E-08  0.2895446082E+02  
  0.6881911871E-03  0.3398285678E+02 -0.1188380629E-08  0.3058743542E+02  
  0.7881911871E-03  0.3543343976E+02 -0.4837454018E-09  0.3201258858E+02  
  0.8881911871E-03  0.3672123264E+02  0.2170841621E-09  0.3327675804E+02  
  0.9440955935E-03  0.3738207696E+02  0.5303713598E-09  0.3392511328E+02  
  0.1000000000E-02  0.3800704159E+02  0.7553195951E-09  0.3453805951E+02  
  0.1055904406E-02  0.3859977534E+02  0.8831469722E-09  0.3511921690E+02  
  0.1111808813E-02  0.3916340096E+02  0.9122712104E-09  0.3567168132E+02  
  0.1279522032E-02  0.4070828133E+02  0.4806659684E-09  0.3718528511E+02  
  0.1595749798E-02  0.4315916825E+02 -0.1685413667E-08  0.3958467114E+02  
  0.1911977564E-02  0.4516770774E+02 -0.4426062011E-08  0.4154942701E+02  
  0.2228205330E-02  0.4687114664E+02 -0.6678232062E-08  0.4321487843E+02  
  0.2544433096E-02  0.4835030884E+02 -0.8067399801E-08  0.4466061794E+02  
  0.2860660862E-02  0.4965738062E+02 -0.8649053813E-08  0.4593799576E+02  
  0.3162277660E-02  0.5077649417E+02 -0.8653847598E-08  0.4703170131E+02  
  0.3463894458E-02  0.5179412206E+02 -0.8341931242E-08  0.4802633883E+02  
  0.3765511256E-02  0.5272704715E+02 -0.7894595808E-08  0.4893835266E+02  
  0.4670361649E-02  0.5514664688E+02 -0.6844500636E-08  0.5130477442E+02  
  0.5670361649E-02  0.5731879736E+02 -0.6818685358E-08  0.5343090085E+02  
  0.6670361649E-02  0.5913263441E+02 -0.7807761107E-08  0.5520773780E+02  
  0.7670361649E-02  0.6069071840E+02 -0.8954540419E-08  0.5673507697E+02  
  0.8670361649E-02  0.6205655755E+02 -0.9577074141E-08  0.5807473176E+02  
  0.9335180825E-02  0.6287872373E+02 -0.9533050056E-08  0.5888147923E+02  
  0.1000000000E-01  0.6364429697E+02 -0.9096926456E-08  0.5963291772E+02  
  0.1066481918E-01  0.6436051176E+02 -0.8312044816E-08  0.6033610254E+02  
  0.1132963835E-01  0.6503330421E+02 -0.7252326773E-08  0.6099682574E+02  
  0.1332409588E-01  0.6684236823E+02 -0.3413484608E-08  0.6277424387E+02  
  0.1648637354E-01  0.6921895507E+02  0.2004082180E-08  0.6511122126E+02  
  0.1964865120E-01  0.7116706684E+02  0.5136572635E-08  0.6702875062E+02  
  0.2281092886E-01  0.7281986241E+02  0.7181404169E-08  0.6865697357E+02  
  0.2597320652E-01  0.7425572908E+02  0.9638989661E-08  0.7007243017E+02  
  0.2913548418E-01  0.7552525800E+02  0.1225654208E-07  0.7132448841E+02  
  0.3162277660E-01  0.7642937574E+02  0.1358620216E-07  0.7221639916E+02  
  0.3411006903E-01  0.7726485725E+02  0.1360671228E-07  0.7304070598E+02  
  0.3659736145E-01  0.7804137757E+02  0.1214324729E-07  0.7380689494E+02  
  0.4405923872E-01  0.8009626474E+02  0.2593546268E-08  0.7583460881E+02  
  0.5405923872E-01  0.8235864831E+02 -0.9780685019E-08  0.7806770981E+02  
  0.6405923872E-01  0.8422904461E+02 -0.1136826496E-07  0.7991533102E+02  
  0.7405923872E-01  0.8582516601E+02 -0.5009148248E-08  0.8149418722E+02  
  0.8405923872E-01  0.8721773258E+02  0.1128398976E-08  0.8287421066E+02  
  0.9405923872E-01  0.8845298286E+02  0.3617597186E-08  0.8410090283E+02  
  0.1000000000E+00  0.8912513436E+02  0.3616255238E-08  0.8476960207E+02  
  0.1059407613E+00  0.8975854919E+02  0.3083036498E-08  0.8540061275E+02  
  0.1118815226E+00  0.9035742371E+02  0.2348588592E-08  0.8599802234E+02  
  0.1297038064E+00  0.9198416653E+02  0.4764624439E-09  0.8762495020E+02  
  0.1613265830E+00  0.9439022104E+02 -0.6778174622E-09  0.9004379191E+02  
  0.1929493596E+00  0.9635459863E+02 -0.3416253246E-09  0.9203148197E+02  
  0.2245721362E+00  0.9801703272E+02  0.4086781312E-12  0.9372334099E+02  
  0.2561949128E+00  0.9945852366E+02  0.1693508875E-09  0.9519795317E+02  
  0.2878176894E+00  0.1007308307E+03  0.1603815942E-09  0.9650569041E+02  
  0.3162277660E+00  0.1017585450E+03  0.4349684848E-10  0.9756650379E+02  
  0.3446378426E+00  0.1026968760E+03 -0.6765183522E-10  0.9853869127E+02  
  0.3730479192E+00  0.1035598119E+03 -0.1204002345E-09  0.9943594172E+02  
  0.4582781491E+00  0.1058058365E+03 -0.6777391652E-10  0.1017853664E+03  
  0.5582781491E+00  0.1079417468E+03  0.2954341445E-10  0.1040402401E+03  
  0.6582781491E+00  0.1097062874E+03 -0.7518771824E-11  0.1059178643E+03  
  0.7582781491E+00  0.1112062181E+03 -0.4460098934E-10  0.1075232048E+03  
  0.8582781491E+00  0.1125074177E+03 -0.2833609378E-10  0.1089214999E+03  
  0.9582781491E+00  0.1136537245E+03 -0.7289579030E-11  0.1101566200E+03  
  0.1000000000E+01  0.1140931947E+03 -0.4309369530E-11  0.1106307667E+03  
  0.1041721851E+01  0.1145130523E+03 -0.4764435248E-11  0.1110839650E+03  
  0.1083443702E+01  0.1149148154E+03 -0.7761574296E-11  0.1115177780E+03  
  0.1208609255E+01  0.1160262273E+03 -0.2384649564E-10  0.1127181611E+03  
  0.1524837021E+01  0.1183511874E+03 -0.8239248846E-10  0.1152275571E+03  
  0.1841064787E+01  0.1201646872E+03 -0.1632504481E-09  0.1171794495E+03  
  0.2157292553E+01  0.1216389796E+03 -0.2500602941E-09  0.1187597047E+03  
  0.2473520319E+01  0.1228713195E+03 -0.2842731800E-09  0.1200749673E+03  
  0.2789748085E+01  0.1239228774E+03 -0.2330678438E-09  0.1211927162E+03  
  0.2976012872E+01  0.1244739336E+03 -0.1727096661E-09  0.1217766373E+03  
  0.3162277660E+01  0.1249832751E+03 -0.1078613745E-09  0.1223152402E+03  
  0.3348542448E+01  0.1254559591E+03 -0.5124820366E-10  0.1228141036E+03  
  0.3534807236E+01  0.1258962175E+03 -0.1152425206E-10  0.1232778896E+03  
  0.4093601599E+01  0.1270599049E+03 -0.3920522288E-11  0.1244999411E+03  
  0.5093601599E+01  0.1287028097E+03 -0.1249374905E-09  0.1262154687E+03  
  0.6093601599E+01  0.1299542542E+03  0.9348182340E-11  0.1275140237E+03  
  0.7093601599E+01  0.1309513303E+03  0.4830224952E-09  0.1285438619E+03  
  0.8093601599E+01  0.1317707795E+03  0.8463453955E-09  0.1293872129E+03  
  0.9093601599E+01  0.1324600722E+03  0.6639457384E-09  0.1300945831E+03  
  0.1000000000E+02  0.1329985518E+03  0.1252374778E-11  0.1306459350E+03  
  0.1090639840E+02  0.1334723798E+03 -0.8234584597E-09  0.1311302211E+03  
  0.1181279680E+02  0.1338935503E+03 -0.1357362626E-08  0.1315600239E+03  
  0.1453199201E+02  0.1349306849E+03  0.1915392303E-08  0.1326160488E+03  
  0.1769426967E+02  0.1358289524E+03  0.1473423577E-07  0.1335277771E+03  
  0.2085654733E+02  0.1365181256E+03  0.3290631167E-07  0.1342256151E+03  
  0.2401882499E+02  0.1370694725E+03  0.5650508442E-07  0.1347829528E+03  
  0.2718110265E+02  0.1375238679E+03  0.1026298974E-06  0.1352417007E+03  
  0.3034338031E+02  0.1379068763E+03  0.2064298901E-06  0.1356279911E+03  
  0.3162277660E+02  0.1380452842E+03  0.2734967623E-06  0.1357674983E+03  
  0.3290217290E+02  0.1381757797E+03  0.3601813455E-06  0.1358989917E+03  
  0.3418156919E+02  0.1382990843E+03  0.4693472715E-06  0.1360232054E+03  
  0.3801975808E+02  0.1386326662E+03  0.9769220771E-06  0.1363590928E+03  
  0.4801975808E+02  0.1393147314E+03  0.5206258929E-05  0.1370452135E+03  
  0.5801975808E+02  0.1398088974E+03  0.1879176215E-04  0.1375417237E+03  
  0.6801975808E+02  0.1401898525E+03  0.5452950428E-04  0.1379241985E+03  
  0.7801975808E+02  0.1404954985E+03  0.1361244412E-03  0.1382308983E+03  
  0.8801975808E+02  0.1407479007E+03  0.3026460692E-03  0.1384840676E+03  
  0.9400987904E+02  0.1408793031E+03  0.4633021619E-03  0.1386158335E+03  
  0.1000000000E+03  0.1409989035E+03  0.6882698380E-03  0.1387357451E+03  
  0.1059901210E+03  0.1411083609E+03  0.9932202971E-03  0.1388454712E+03  
  0.1119802419E+03  0.1412090266E+03  0.1394167444E-02  0.1389463708E+03  
  0.1299506048E+03  0.1414697605E+03  0.3349176226E-02  0.1392076576E+03  
  0.1615733814E+03  0.1418200897E+03  0.1025637331E-01  0.1395586100E+03  
  0.1931961580E+03  0.1420786558E+03  0.2231467368E-01  0.1398175482E+03  
  0.2248189346E+03  0.1422803316E+03  0.3974759138E-01  0.1400194693E+03  
  0.2564417112E+03  0.1424435695E+03  0.6216313645E-01  0.1401828791E+03  
  0.2880644878E+03  0.1425794130E+03  0.8889965736E-01  0.1403188481E+03  
  0.3162277660E+03  0.1426831228E+03  0.1157810741E+00  0.1404226430E+03  
  0.3443910442E+03  0.1427743596E+03  0.1450546049E+00  0.1405139468E+03  
  0.3725543224E+03  0.1428557257E+03  0.1763084136E+00  0.1405953663E+03  
  0.4570441571E+03  0.1430602509E+03  0.2783413664E+00  0.1407999989E+03  
  0.5570441571E+03  0.1432526717E+03  0.4097295979E+00  0.1409924826E+03  
  0.6570441571E+03  0.1434182579E+03  0.5469989704E+00  0.1411580979E+03  
  0.7570441571E+03  0.1435714183E+03  0.6870082908E+00  0.1413112717E+03  
  0.8570441571E+03  0.1437188170E+03  0.8282952487E+00  0.1414586766E+03  
  0.9570441571E+03  0.1438635444E+03  0.9701794589E+00  0.1416034069E+03  
  0.1000000000E+04  0.1439252644E+03  0.1031228324E+01  0.1416651276E+03  
  0.1042955843E+04  0.1439868366E+03  0.1092310924E+01  0.1417267003E+03  
  0.1085911686E+04  0.1440483014E+03  0.1153418264E+01  0.1417881654E+03  
  0.1214779215E+04  0.1442323265E+03  0.1336826466E+01  0.1419721911E+03  
  0.1531006981E+04  0.1446829894E+03  0.1787111514E+01  0.1424228544E+03  
  0.1847234747E+04  0.1451333342E+03  0.2237479087E+01  0.1428731991E+03  
  0.2163462513E+04  0.1455837024E+03  0.2687844485E+01  0.1433235673E+03  
  0.2479690279E+04  0.1460340688E+03  0.3138210896E+01  0.1437739338E+03  
  0.2795918045E+04  0.1464844354E+03  0.3588577420E+01  0.1442243003E+03  
  0.2979097852E+04  0.1467453172E+03  0.3849459188E+01  0.1444851821E+03  
  0.3162277660E+04  0.1470061989E+03  0.4110340960E+01  0.1447460639E+03  
  0.3345457468E+04  0.1472670807E+03  0.4371222733E+01  0.1450069457E+03  
  0.3528637276E+04  0.1475279625E+03  0.4632104507E+01  0.1452678274E+03  
  0.4078176699E+04  0.1483106078E+03  0.5414749829E+01  0.1460504727E+03  
  0.5078176699E+04  0.1497347919E+03  0.6838933956E+01  0.1474746569E+03  
  0.6078176699E+04  0.1511589761E+03  0.8263118083E+01  0.1488988410E+03  
  0.7078176699E+04  0.1525831602E+03  0.9687302210E+01  0.1503230251E+03  
  0.8078176699E+04  0.1540073443E+03  0.1111148634E+02  0.1517472093E+03  
  0.9078176699E+04  0.1554315284E+03  0.1253567046E+02  0.1531713934E+03  
  0.1000000000E+05  0.1567443746E+03  0.1384851658E+02  0.1544842395E+03  
  0.1092182330E+05  0.1580572207E+03  0.1516136269E+02  0.1557970856E+03  
  0.1184364660E+05  0.1593700668E+03  0.1647420880E+02  0.1571099317E+03  
  0.1460911651E+05  0.1633086051E+03  0.2041274715E+02  0.1610484701E+03  
  0.1777139417E+05  0.1678122708E+03  0.2491641279E+02  0.1655521357E+03  
  0.2093367183E+05  0.1723159364E+03  0.2942007844E+02  0.1700558014E+03  
  0.2409594949E+05  0.1768196021E+03  0.3392374409E+02  0.1745594670E+03  
  0.2725822715E+05  0.1813232677E+03  0.3842740974E+02  0.1790631327E+03  
  0.3042050481E+05  0.1858269334E+03  0.4293107539E+02  0.1835667983E+03  
  0.3162277660E+05  0.1875391898E+03  0.4464333179E+02  0.1852790547E+03  
  0.3282504840E+05  0.1892514462E+03  0.4635558820E+02  0.1869913111E+03  
  0.3402732019E+05  0.1909637026E+03  0.4806784461E+02  0.1887035675E+03  
  0.3763413557E+05  0.1961004718E+03  0.5320461382E+02  0.1938403367E+03  
  0.4763413557E+05  0.2103423131E+03  0.6744645509E+02  0.2080821780E+03  
  0.5763413557E+05  0.2245841543E+03  0.8168829636E+02  0.2223240193E+03  
  0.6763413557E+05  0.2388259956E+03  0.9593013763E+02  0.2365658605E+03  
  0.7763413557E+05  0.2530678369E+03  0.1101719789E+03  0.2508077018E+03  
  0.8763413557E+05  0.2673096781E+03  0.1244138202E+03  0.2650495431E+03  
  0.9381706779E+05  0.2761153121E+03  0.1332194541E+03  0.2738551770E+03  
  0.1000000000E+06  0.2849209460E+03  0.1420250880E+03  0.2826608109E+03  
  0.1061829322E+06  0.2937265799E+03  0.1508307219E+03  0.2914664448E+03  
  0.1123658644E+06  0.3025322138E+03  0.1596363558E+03  0.3002720788E+03  
  0.1309146611E+06  0.3289491156E+03  0.1860532576E+03  0.3266889805E+03  
  0.1625374377E+06  0.3739857721E+03  0.2310899141E+03  0.3717256370E+03  
  0.1941602143E+06  0.4190224285E+03  0.2761265706E+03  0.4167622935E+03  
  0.2257829909E+06  0.4640590850E+03  0.3211632270E+03  0.4617989500E+03  
  0.2574057675E+06  0.5090957415E+03  0.3661998835E+03  0.5068356065E+03  
  0.2890285441E+06  0.5541323980E+03  0.4112365400E+03  0.5518722629E+03  
  0.3162277660E+06  0.5928690981E+03  0.4499732402E+03  0.5906089631E+03  
  0.3434269880E+06  0.6316057983E+03  0.4887099403E+03  0.6293456632E+03  
  0.3706262099E+06  0.6703424984E+03  0.5274466405E+03  0.6680823634E+03  
  0.4522238757E+06  0.7865525989E+03  0.6436567409E+03  0.7842924638E+03  
  0.5522238757E+06  0.9289710116E+03  0.7860751536E+03  0.9267108765E+03  
  0.6522238757E+06  0.1071389424E+04  0.9284935663E+03  0.1069129289E+04  
  0.7522238757E+06  0.1213807837E+04  0.1070911979E+04  0.1211547702E+04  
  0.8522238757E+06  0.1356226250E+04  0.1213330392E+04  0.1353966115E+04  
  0.9522238757E+06  0.1498644662E+04  0.1355748804E+04  0.1496384527E+04  
  0.1000000000E+07  0.1566686660E+04  0.1423790802E+04  0.1564426525E+04"""  

    timescale = 1e-6
    data= numpy.array([ map(float,line.split()) for line in datastr.split('\n')])
    t=data[:,0]*timescale
    maxTwire=data[:,1]
    maxTsubstrate=data[:,3]
    minTsubstrate=data[:,2]
    return t,maxTwire,maxTsubstrate,minTsubstrate


def nanowirewithnotchonSiN():
    """returns tuple of numpy.array objects:

    (time, max(T) in nanowire, max(T) in substrate, min(T) in substrate)

    for Nanowire with notch on SiN substrate membrane case study
    (section 3C in publication).

    source file: results/notch_3d_SiN/all_time_temp.dat
    """

    datastr = """  0.1000720779E-07  0.0000000000E+00  0.0000000000E+00  0.0000000000E+00  
  0.2001441557E-07  0.1607643027E-02  0.9668759331E-80  0.3913922886E-03  
  0.5003603893E-07  0.1140681401E-01  0.5031512281E-79  0.2754264566E-02  
  0.1401009090E-06  0.4196633753E-01  0.6088345816E-79  0.1012250478E-01  
  0.2301657791E-06  0.7331816752E-01  0.1555812870E-79  0.1799403964E-01  
  0.5003603893E-06  0.1656767076E+00 -0.4398393646E-79  0.4409293979E-01  
  0.8165881553E-06  0.2677044646E+00 -0.2208617871E-79  0.7776202567E-01  
  0.1132815921E-05  0.3631257749E+00  0.1665083491E-80  0.1131762952E+00  
  0.1449043687E-05  0.4534838372E+00  0.9220242697E-80  0.1495293086E+00  
  0.1765271453E-05  0.5398400692E+00  0.9934929956E-80  0.1864640665E+00  
  0.2081499219E-05  0.6229321087E+00  0.7459129047E-80  0.2238149059E+00  
  0.2397726985E-05  0.7032746323E+00  0.4587315524E-80  0.2615005008E+00  
  0.2713954751E-05  0.7812397665E+00  0.2096047697E-80  0.2994712777E+00  
  0.3030182517E-05  0.8571042671E+00  0.3183073183E-81  0.3376911846E+00  
  0.3162277660E-05  0.8882201841E+00 -0.2215189709E-81  0.3537235298E+00  
  0.3294372803E-05  0.9190211477E+00 -0.6522465687E-81  0.3697917218E+00  
  0.3426467946E-05  0.9495189421E+00 -0.9870215480E-81  0.3858936656E+00  
  0.3822753374E-05  0.1039314698E+01 -0.1550632465E-80  0.4343776679E+00  
  0.4822753374E-05  0.1255927868E+01 -0.1411291810E-80  0.5575928564E+00  
  0.5822753374E-05  0.1460140688E+01 -0.5565052683E-81  0.6815483272E+00  
  0.6822753374E-05  0.1654075675E+01  0.8190821005E-83  0.8056324310E+00  
  0.7822753374E-05  0.1839276520E+01  0.2191297223E-81  0.9293893829E+00  
  0.8822753374E-05  0.2016933385E+01  0.2320359087E-81  0.1052498108E+01  
  0.9411376687E-05  0.2118344376E+01  0.1978272339E-81  0.1124572762E+01  
  0.1000000000E-04  0.2217639010E+01  0.1556337707E-81  0.1196312484E+01  
  0.1058862331E-04  0.2314959772E+01  0.1137897056E-81  0.1267693613E+01  
  0.1117724663E-04  0.2410433942E+01  0.7667502868E-82  0.1338698227E+01  
  0.1294311656E-04  0.2687026944E+01  0.3466015542E-83  0.1549331706E+01  
  0.1610539423E-04  0.3151159023E+01 -0.2773005954E-82  0.1917391342E+01  
  0.1926767189E-04  0.3582674914E+01 -0.1037446400E-82  0.2273844476E+01  
  0.2242994955E-04  0.3988480317E+01  0.5416501680E-84  0.2619296532E+01  
  0.2559222721E-04  0.4373301859E+01  0.2208863019E-83  0.2954571971E+01  
  0.2875450487E-04  0.4740569443E+01  0.1335958221E-83  0.3280503875E+01  
  0.3162277660E-04  0.5060669781E+01  0.5677079798E-84  0.3568696552E+01  
  0.3449104834E-04  0.5369998910E+01  0.1560315181E-84  0.3850374890E+01  
  0.3735932007E-04  0.5669791866E+01 -0.8626204274E-86  0.4126019271E+01  
  0.4596413528E-04  0.6522568652E+01 -0.5862965311E-85  0.4921498307E+01  
  0.5596413528E-04  0.7441947980E+01  0.1403294011E-85  0.5794797599E+01  
  0.6596413528E-04  0.8302955545E+01  0.2270593926E-86  0.6623370012E+01  
  0.7596413528E-04  0.9118794636E+01 -0.2788379951E-86  0.7415390089E+01  
  0.8596413528E-04  0.9898398629E+01 -0.1469690482E-86  0.8176897591E+01  
  0.9596413528E-04  0.1064813286E+02 -0.5477136839E-87  0.8912470902E+01  
  0.1000000000E-03  0.1094326417E+02 -0.2056766047E-87  0.9202746183E+01  
  0.1040358647E-03  0.1123458139E+02  0.1376468730E-88  0.9489593149E+01  
  0.1080717294E-03  0.1152230769E+02  0.1461605051E-87  0.9773188174E+01  
  0.1201793236E-03  0.1236616231E+02  0.2590366284E-87  0.1060625443E+02  
  0.1518021002E-03  0.1445803967E+02  0.4178035491E-88  0.1267723417E+02  
  0.1834248768E-03  0.1641956425E+02 -0.5682817444E-88  0.1462388550E+02  
  0.2150476534E-03  0.1828244372E+02 -0.4568732220E-89  0.1647433301E+02  
  0.2466704300E-03  0.2006545425E+02  0.6245900889E-89  0.1824602912E+02  
  0.2782932066E-03  0.2178095331E+02  0.2362894791E-89  0.1995081017E+02  
  0.2972604863E-03  0.2278106168E+02  0.6253906565E-90  0.2094468895E+02  
  0.3162277660E-03  0.2376161860E+02 -0.2004901544E-90  0.2191913973E+02  
  0.3351950457E-03  0.2472388361E+02 -0.4089092357E-90  0.2287541616E+02  
  0.3541623254E-03  0.2566895601E+02 -0.2393242962E-90  0.2381461583E+02  
  0.4110641645E-03  0.2841155221E+02 -0.2268204010E-91  0.2654029665E+02  
  0.5110641645E-03  0.3293983929E+02  0.5910493332E-91  0.3104142598E+02  
  0.6110641645E-03  0.3715527197E+02 -0.5088041597E-91  0.3523287423E+02  
  0.7110641645E-03  0.4111288956E+02  0.4008607894E-91  0.3916938536E+02  
  0.8110641645E-03  0.4485140868E+02 -0.3328608125E-91  0.4288929641E+02  
  0.9110641645E-03  0.4839978984E+02  0.3232488343E-91  0.4642121923E+02  
  0.1000000000E-02  0.5141395029E+02 -0.3110447061E-91  0.4942231823E+02  
  0.1088935835E-02  0.5430864888E+02  0.3188364011E-91  0.5230526254E+02  
  0.1177871671E-02  0.5709475539E+02 -0.3113051516E-91  0.5508078541E+02  
  0.1444679177E-02  0.6490112753E+02  0.3183057700E-91  0.6286119855E+02  
  0.1760906943E-02  0.7325089951E+02 -0.3119454229E-91  0.7118936143E+02  
  0.2077134709E-02  0.8083126846E+02  0.3176683902E-91  0.7875545465E+02  
  0.2393362475E-02  0.8780689752E+02 -0.3119424160E-91  0.8572208011E+02  
  0.2709590241E-02  0.9429805774E+02  0.3173827227E-91  0.9220800796E+02  
  0.3025818007E-02  0.1003949008E+03 -0.3116619282E-91  0.9830229487E+02  
  0.3162277660E-02  0.1029202884E+03  0.3169104489E-91  0.1008272153E+03  
  0.3298737313E-02  0.1053900969E+03 -0.3109252475E-91  0.1032968495E+03  
  0.3435196966E-02  0.1078083424E+03  0.3161263940E-91  0.1057151710E+03  
  0.3844575924E-02  0.1147931655E+03 -0.3104087589E-91  0.1127013292E+03  
  0.4844575924E-02  0.1305143932E+03  0.3157475885E-91  0.1284296437E+03  
  0.5844575924E-02  0.1447859654E+03 -0.3106884812E-91  0.1427103701E+03  
  0.6844575924E-02  0.1580327962E+03  0.3151517207E-91  0.1559660414E+03  
  0.7844575924E-02  0.1704914268E+03 -0.3110280581E-91  0.1684325918E+03  
  0.8844575924E-02  0.1823096178E+03  0.3146433073E-91  0.1802577344E+03  
  0.9422287962E-02  0.1888838671E+03 -0.3111313968E-91  0.1868355947E+03  
  0.1000000000E-01  0.1952942965E+03  0.3142735297E-91  0.1932493746E+03  
  0.1057771204E-01  0.2015535300E+03 -0.3110663595E-91  0.1995117239E+03  
  0.1115542408E-01  0.2076725169E+03  0.3139407587E-91  0.2056336158E+03  
  0.1288856019E-01  0.2252915868E+03 -0.3111001180E-91  0.2232603624E+03  
  0.1605083785E-01  0.2550594717E+03  0.3136884757E-91  0.2530392410E+03  
  0.1921311551E-01  0.2823554713E+03 -0.3111490267E-91  0.2803435336E+03  
  0.2237539317E-01  0.3077296784E+03  0.3136185542E-91  0.3057243005E+03  
  0.2553767083E-01  0.3315473316E+03 -0.3111891095E-91  0.3295473167E+03  
  0.2869994849E-01  0.3540683716E+03  0.3134489003E-91  0.3520728502E+03  
  0.3162277660E-01  0.3738981386E+03 -0.3112963506E-91  0.3719061820E+03  
  0.3454560471E-01  0.3929052707E+03  0.3132614099E-91  0.3909164367E+03  
  0.3746843282E-01  0.4111849400E+03 -0.3113937671E-91  0.4091988714E+03  
  0.4623691716E-01  0.4624651028E+03  0.3129972194E-91  0.4604858128E+03  
  0.5623691716E-01  0.5155977317E+03 -0.3116817544E-91  0.5136241851E+03  
  0.6623691716E-01  0.5643655260E+03  0.3124859078E-91  0.5623964085E+03  
  0.7623691716E-01  0.6097003834E+03 -0.3158342694E-91  0.6077348422E+03  
  0.8623691716E-01  0.6522367157E+03  0.2766177555E-91  0.6502741640E+03  
  0.9623691716E-01  0.6924310825E+03 -0.5567691731E-91  0.6904710995E+03  
  0.1000000000E+00  0.7070157952E+03 -0.1175991972E-91  0.7050566916E+03  
  0.1037630828E+00  0.7213343741E+03 -0.1060763907E-90  0.7193761112E+03  
  0.1075261657E+00  0.7354003376E+03 -0.9790364220E-91  0.7334428804E+03  
  0.1188154142E+00  0.7762202714E+03 -0.8439520045E-90  0.7742650576E+03  
  0.1504381908E+00  0.8814429234E+03 -0.1720104755E-87  0.8794930301E+03  
  0.1820609674E+00  0.9757493010E+03 -0.1736831530E-86  0.9738038008E+03  
  0.2136837440E+00  0.1061816729E+04 -0.9188310467E-86  0.1059875122E+04  
  0.2453065206E+00  0.1141321194E+04 -0.3286935993E-85  0.1139383164E+04  
  0.2769292972E+00  0.1215410887E+04 -0.8849048976E-85  0.1213476201E+04  
  0.2965785316E+00  0.1259077032E+04 -0.1458531342E-84  0.1257144326E+04  
  0.3162277660E+00  0.1301141716E+04 -0.2238712750E-84  0.1299210926E+04  
  0.3358770004E+00  0.1341738282E+04 -0.3216968252E-84  0.1339809345E+04  
  0.3555262348E+00  0.1380982097E+04 -0.4354092814E-84  0.1379054957E+04  
  0.4144739380E+00  0.1491680522E+04 -0.7913274255E-84  0.1489758454E+04  
  0.5144739380E+00  0.1659480157E+04 -0.1157943541E-83  0.1657565727E+04  
  0.6144739380E+00  0.1807346524E+04 -0.1104733178E-83  0.1805438679E+04  
  0.7144739380E+00  0.1939889270E+04 -0.8536470753E-84  0.1937987132E+04  
  0.8144739380E+00  0.2060183443E+04 -0.6097829726E-84  0.2058286282E+04  
  0.9144739380E+00  0.2170419140E+04 -0.7430266808E-85  0.2168526349E+04  
  0.1000000000E+01  0.2257938243E+04  0.1605849674E-83  0.2256048781E+04  
  0.1085526062E+01  0.2340098466E+04  0.7183070757E-83  0.2338212014E+04  
  0.1171052124E+01  0.2417542031E+04  0.2350999523E-82  0.2415658313E+04  
  0.1427630310E+01  0.2627071569E+04  0.2331710288E-80  0.2625194762E+04  
  0.1743858076E+01  0.2847684486E+04  0.6008669608E-79  0.2845814168E+04  
  0.2060085842E+01  0.3037595752E+04  0.4174915396E-78  0.3035730398E+04  
  0.2376313608E+01  0.3204536818E+04  0.2105029934E-77  0.3202675392E+04  
  0.2692541374E+01  0.3353574682E+04  0.1696622149E-76  0.3351716443E+04  
  0.3008769140E+01  0.3488236316E+04  0.1588056787E-75  0.3486380717E+04  
  0.3162277660E+01  0.3549156956E+04  0.4983952998E-75  0.3547302479E+04  
  0.3315786180E+01  0.3607551367E+04  0.6350208013E-75  0.3605697927E+04  
  0.3469294701E+01  0.3663621641E+04  0.2862679346E-74  0.3661769163E+04  
  0.3929820262E+01  0.3819822247E+04  0.5767001396E-73  0.3817972280E+04  
  0.4929820262E+01  0.4110139716E+04  0.1234953201E-69  0.4108293828E+04  
  0.5929820262E+01  0.4350065106E+04  0.2710339536E-68  0.4348222034E+04  
  0.6929820262E+01  0.4554848881E+04  0.3140145164E-67  0.4553007881E+04  
  0.7929820262E+01  0.4733576662E+04  0.2553851778E-66  0.4731737254E+04  
  0.8929820262E+01  0.4892172304E+04  0.1551835286E-65  0.4890334158E+04  
  0.9464910131E+01  0.4970148299E+04  0.3444606248E-65  0.4968310726E+04  
  0.1000000000E+02  0.5044058356E+04  0.7654525151E-65  0.5042221299E+04  
  0.1053508987E+02  0.5114303617E+04  0.1475907105E-64  0.5112467026E+04  
  0.1107017974E+02  0.5181228897E+04  0.3294082113E-64  0.5179392732E+04  
  0.1267544935E+02  0.5365269703E+04  0.3262490410E-63  0.5363434617E+04  
  0.1583772701E+02  0.5670934774E+04  0.5600907224E-62  0.5669101214E+04  
  0.1900000467E+02  0.5921209452E+04  0.2762729092E-60  0.5919376915E+04  
  0.2216228233E+02  0.6133448398E+04  0.8227655294E-59  0.6131616599E+04  
  0.2532455999E+02  0.6317791589E+04  0.5299589393E-58  0.6315960349E+04  
  0.2848683765E+02  0.6480759901E+04  0.3669124420E-57  0.6478929099E+04  
  0.3162277660E+02  0.6625652193E+04  0.4940548938E-57  0.6623821739E+04  
  0.3475871556E+02  0.6757025710E+04 -0.2724105764E-56  0.6755195545E+04  
  0.3789465451E+02  0.6877191015E+04 -0.5049555636E-55  0.6875361091E+04  
  0.4730247137E+02  0.7187928942E+04  0.1652358613E-51  0.7186099560E+04  
  0.5730247137E+02  0.7456144688E+04  0.7477876409E-50  0.7454315685E+04  
  0.6730247137E+02  0.7681012900E+04  0.1098694042E-48  0.7679184164E+04  
  0.7730247137E+02  0.7874749183E+04  0.9507218356E-48  0.7872920644E+04  
  0.8730247137E+02  0.8044981550E+04  0.5286921860E-47  0.8043153164E+04  
  0.9365123569E+02  0.8143153120E+04  0.1331881621E-46  0.8141324814E+04  
  0.1000000000E+03  0.8234945194E+04  0.3009824695E-46  0.8233116957E+04  
  0.1063487643E+03  0.8321133502E+04  0.6093931567E-46  0.8319305327E+04  
  0.1126975286E+03  0.8402360910E+04  0.1033383285E-45  0.8400532790E+04  
  0.1317438216E+03  0.8621903508E+04  0.2058334136E-43  0.8620075522E+04  
  0.1633665982E+03  0.8925173776E+04  0.1660669679E-35  0.8923345945E+04  
  0.1949893748E+03  0.9173775616E+04  0.1089648001E-33  0.9171947889E+04  
  0.2266121514E+03  0.9384755522E+04  0.3600593795E-32  0.9382927869E+04  
  0.2582349280E+03  0.9568108817E+04  0.7980260845E-31  0.9566281220E+04  
  0.2898577046E+03  0.9730274461E+04  0.1333476567E-29  0.9728446909E+04  
  0.3162277660E+03  0.9852468268E+04  0.8544127919E-29  0.9850640745E+04  
  0.3425978275E+03  0.9964909770E+04  0.5237666597E-28  0.9963082273E+04  
  0.3689678889E+03  0.1006903987E+05  0.3065894590E-27  0.1006721240E+05  
  0.4480780732E+03  0.1034313754E+05  0.4094231029E-20  0.1034131011E+05  
  0.5480780732E+03  0.1062710282E+05  0.4720322042E-17  0.1062527544E+05  
  0.6480780732E+03  0.1086275248E+05  0.1556637570E-15  0.1086092513E+05  
  0.7480780732E+03  0.1106437306E+05  0.2675521226E-14  0.1106254573E+05  
  0.8480780732E+03  0.1124063159E+05  0.3125119480E-13  0.1123880428E+05  
  0.9480780732E+03  0.1139722824E+05  0.2766078961E-12  0.1139540094E+05  
  0.1000000000E+04  0.1147205402E+05  0.6565917412E-12  0.1147022672E+05  
  0.1051921927E+04  0.1154311666E+05  0.1535521628E-11  0.1154128937E+05  
  0.1103843854E+04  0.1161077487E+05  0.3534676269E-11  0.1160894758E+05  
  0.1259609634E+04  0.1179662639E+05  0.1205449469E-09  0.1179479912E+05  
  0.1575837400E+04  0.1211324002E+05  0.9390497063E-07  0.1211141276E+05  
  0.1892065166E+04  0.1237060745E+05  0.1440293532E-05  0.1236878021E+05  
  0.2208292932E+04  0.1258783565E+05  0.1154331204E-04  0.1258600841E+05  
  0.2524520698E+04  0.1277587762E+05  0.6329300066E-04  0.1277405039E+05  
  0.2840748464E+04  0.1294169460E+05  0.2654241369E-03  0.1293986738E+05  
  0.3001513062E+04  0.1301894262E+05  0.4881609073E-03  0.1301711540E+05  
  0.3162277660E+04  0.1309218785E+05  0.8697628508E-03  0.1309036063E+05  
  0.3323042258E+04  0.1316182266E+05  0.1501560175E-02  0.1315999544E+05  
  0.3483806856E+04  0.1322818476E+05  0.2513446649E-02  0.1322635753E+05  
  0.3966100651E+04  0.1341075926E+05  0.1074742954E-01  0.1340893204E+05  
  0.4966100651E+04  0.1372867401E+05  0.1056794683E+00  0.1372684680E+05  
  0.5966100651E+04  0.1398688408E+05  0.4449947598E+00  0.1398505687E+05  
  0.6966100651E+04  0.1420470817E+05  0.1284377580E+01  0.1420288097E+05  
  0.7966100651E+04  0.1439319489E+05  0.2931511455E+01  0.1439136769E+05  
  0.8966100651E+04  0.1455935691E+05  0.5688094242E+01  0.1455752971E+05  
  0.9483050325E+04  0.1463802166E+05  0.7627941132E+01  0.1463619446E+05  
  0.1000000000E+05  0.1471253916E+05  0.9962806409E+01  0.1471071196E+05  
  0.1051694967E+05  0.1478332277E+05  0.1271492396E+02  0.1478149557E+05  
  0.1103389935E+05  0.1485072736E+05  0.1590136142E+02  0.1484890016E+05  
  0.1258474837E+05  0.1503593887E+05  0.2816837115E+02  0.1503411167E+05  
  0.1574702603E+05  0.1535294597E+05  0.6562793419E+02  0.1535111877E+05  
  0.1890930369E+05  0.1561082837E+05  0.1185732406E+03  0.1560900117E+05  
  0.2207158135E+05  0.1582909557E+05  0.1845187728E+03  0.1582726838E+05  
  0.2523385901E+05  0.1601923203E+05  0.2607407874E+03  0.1601740484E+05  
  0.2839613667E+05  0.1618880474E+05  0.3448696473E+03  0.1618697754E+05  
  0.3000945664E+05  0.1626905151E+05  0.3902524551E+03  0.1626722432E+05  
  0.3162277660E+05  0.1634593104E+05  0.4369740010E+03  0.1634410385E+05  
  0.3323609657E+05  0.1641990310E+05  0.4848559284E+03  0.1641807590E+05  
  0.3484941653E+05  0.1649136307E+05  0.5337431536E+03  0.1648953587E+05  
  0.3968937642E+05  0.1669426593E+05  0.6850104101E+03  0.1669243874E+05  
  0.4968937642E+05  0.1707857542E+05  0.1011587176E+04  0.1707674823E+05  
  0.5968937642E+05  0.1743743671E+05  0.1348410758E+04  0.1743560951E+05  
  0.6968937642E+05  0.1778658639E+05  0.1689147077E+04  0.1778475920E+05  
  0.7968937642E+05  0.1813202815E+05  0.2031376981E+04  0.1813020096E+05  
  0.8968937642E+05  0.1847605457E+05  0.2374177153E+04  0.1847422738E+05  
  0.9484468821E+05  0.1865316266E+05  0.2551001365E+04  0.1865133546E+05  
  0.1000000000E+06  0.1883019491E+05  0.2727856141E+04  0.1882836772E+05 """

    timescale = 1e-6
    data= numpy.array([ map(float,line.split()) for line in datastr.split('\n')])
    t=data[:,0]*timescale
    maxTwire=data[:,1]
    maxTsubstrate=data[:,3]
    minTsubstrate=data[:,2]
    return t,maxTwire,maxTsubstrate,minTsubstrate
